==> PyVEP-0.2.1.tar.gz: PyVEP-0.2.1/vep/errors.py <==
# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
#
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the
# License.
#
# The Original Code is PyVEP
#
# The Initial Developer of the Original Code is the Mozilla Foundation.
# Portions created by the Initial Developer are Copyright (C) 2011
# the Initial Developer. All Rights Reserved.
#
# Contributor(s):
#   Ryan Kelly (rkelly@mozilla.com)
#
# Alternatively, the contents of this file may be used under the terms of
# either the GNU General Public License Version 2 or later (the "GPL"), or
# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
#
# ***** END LICENSE BLOCK *****
"""

Error classes for PyVEP.

"""


class Error(Exception):
    """Base error class for all PyVEP exceptions."""
    pass


class ConnectionError(Error):
    """Error raised when PyVEP fails to connect to a remote server."""
    pass


class TrustError(Error):
    """Base error class when assertions are well-formed but untrusted."""
    pass


class InvalidSignatureError(TrustError):
    """Error raised when PyVEP encounters an invalid signature."""
    pass


class ExpiredSignatureError(TrustError):
    """Error raised when PyVEP encounters an expired signature or assertion."""
    pass


class AudienceMismatchError(TrustError):
    """Error raised when the audience does not match."""
    pass

==> PyVEP-0.3.1.tar.gz: PyVEP-0.3.1/vep/errors.py <==
# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
#
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the
# License.
#
# The Original Code is PyVEP
#
# The Initial Developer of the Original Code is the Mozilla Foundation.
# Portions created by the Initial Developer are Copyright (C) 2011
# the Initial Developer. All Rights Reserved.
#
# Contributor(s):
#   Ryan Kelly (rkelly@mozilla.com)
#
# Alternatively, the contents of this file may be used under the terms of
# either the GNU General Public License Version 2 or later (the "GPL"), or
# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
#
# ***** END LICENSE BLOCK *****
"""

Error classes for PyVEP.

"""


class Error(Exception):
    """Base error class for all PyVEP exceptions."""
    pass


class ConnectionError(Error):
    """Error raised when PyVEP fails to connect to a remote server."""
    pass


class TrustError(Error):
    """Base error class when assertions are well-formed but untrusted."""
    pass


class InvalidSignatureError(TrustError):
    """Error raised when PyVEP encounters an invalid signature."""
    pass


class InvalidIssuerError(TrustError):
    """Error raised when a cert is from an invalid/untrusted issuer."""
    pass


class ExpiredSignatureError(TrustError):
    """Error raised when PyVEP encounters an expired signature or assertion."""
    pass


class AudienceMismatchError(TrustError):
    """Error raised when the audience does not match."""
    pass
